## dbt-adapters 1.4.0 - July 30, 2024

### Features

- render 'to' and 'to_columns' fields on foreign key constraints, and bump dbt-common lower bound to 1.6 ([#271](https://github.com/dbt-labs/dbt-adapters/issues/271))

### Fixes

- Incremental table varchar column definition changed ([#276](https://github.com/dbt-labs/dbt-adapters/issues/276))

### Under the Hood

- Rework record/replay to record at the database connection level. ([#244](https://github.com/dbt-labs/dbt-adapters/issues/244))
